@@ -69,6 +69,10 @@ class TransactionOutputRow:
             else:
                 answers[pred_col]['predicted_value'] = prediction_row[pred_col]
 
+            if f'{pred_col}_anomaly' in prediction_row.keys() and \
+                    self._transaction_output._transaction.lmd.get('anomaly_detection', False):
+                answers[pred_col]['anomaly'] = prediction_row[f'{pred_col}_anomaly']
+
             if prediction_row.get(f'{pred_col}_confidence') is not None:
                 answers[pred_col]['confidence'] = round(prediction_row[f'{pred_col}_confidence'], 4)
                 quality = 'very confident'
