@@ -83,6 +83,10 @@ class DataSplitter(BaseModule):
             self.transaction.input_data.validation_df = self.transaction.input_data.data_frame.loc[validation_indexes[NO_GROUP]].copy()
 
             if self.transaction.lmd['tss']['is_timeseries']:
+                ts_train_row_count = len(self.transaction.input_data.train_df)
+                ts_test_row_count = len(self.transaction.input_data.test_df)
+                ts_val_row_count = len(self.transaction.input_data.validation_df)
+
                 historical_train = deepcopy(self.transaction.input_data.train_df)
                 historical_train['make_predictions'] = [False] * len(historical_train)
 
@@ -103,6 +107,12 @@ class DataSplitter(BaseModule):
             self.transaction.lmd['data_preparation']['train_row_count'] = len(self.transaction.input_data.train_df)
             self.transaction.lmd['data_preparation']['validation_row_count'] = len(self.transaction.input_data.validation_df)
 
+            if self.transaction.lmd['tss']['is_timeseries']:
+                # restore original row count (prior to added historical context)
+                self.transaction.lmd['data_preparation']['train_row_count'] = ts_train_row_count
+                self.transaction.lmd['data_preparation']['validation_row_count'] = ts_val_row_count
+                self.transaction.lmd['data_preparation']['test_row_count'] = ts_test_row_count
+
             data = {
                 'subsets': [
                     [len(self.transaction.input_data.train_df), 'Train'],
