@@ -1,3 +1,4 @@
+import dateutil
 import datetime
 import math
 
@@ -23,10 +24,10 @@ def _try_round(x):
         return None
 
 
-def _standardize_date(date_str, fmt):
+def _standardize_date(date_str, dateutil_parser_kwargs):
     try:
         # will return a datetime object
-        date = datetime.datetime.strptime(date_str, fmt)
+        date = dateutil.parser.parse(date_str, **dateutil_parser_kwargs)
     except Exception:
         try:
             date = datetime.datetime.utcfromtimestamp(date_str)
@@ -36,10 +37,10 @@ def _standardize_date(date_str, fmt):
     return date.strftime('%Y-%m-%d')
 
 
-def _standardize_datetime(date_str, fmt):
+def _standardize_datetime(date_str, dateutil_parser_kwargs):
     try:
         # will return a datetime object
-        date = datetime.datetime.strptime(date_str, fmt)
+        date = dateutil.parser.parse(date_str, **dateutil_parser_kwargs)
     except Exception:
         try:
             date = datetime.datetime.utcfromtimestamp(date_str)
@@ -115,23 +116,17 @@ class DataTransformer(BaseModule):
                     self._apply_to_all_data(input_data, column, _try_round, transaction_type)
 
             if data_type == DATA_TYPES.DATE:
-                if data_subtype == DATA_SUBTYPES.DATE:
-                    self._apply_to_all_data(
-                        input_data,
-                        column,
-                        _standardize_date,
-                        transaction_type,
-                        fmt=self.transaction.lmd['stats_v2'][column]['additional_info']['date_fmt']
-                    )
-
-                elif data_subtype == DATA_SUBTYPES.TIMESTAMP:
-                    self._apply_to_all_data(
-                        input_data,
-                        column,
-                        _standardize_datetime,
-                        transaction_type,
-                        fmt=self.transaction.lmd['stats_v2'][column]['additional_info']['date_fmt']
-                    )
+                fn = _standardize_datetime if data_subtype == DATA_SUBTYPES.TIMESTAMP else _standardize_date
+                self._apply_to_all_data(
+                    input_data,
+                    column,
+                    fn,
+                    transaction_type,
+                    dateutil_parser_kwargs=self.transaction.lmd.get('dateutil_parser_kwargs_per_column', {}).get(column, {})
+                )
+                if self.transaction.hmd['model_backend'] == 'lightwood':
+                    self._apply_to_all_data(input_data, column, _lightwood_datetime_processing, transaction_type)
+                    self._apply_to_all_data(input_data, column, _handle_nan, transaction_type)
 
             if data_type == DATA_TYPES.CATEGORICAL:
                 if data_subtype == DATA_SUBTYPES.TAGS:
@@ -146,12 +141,6 @@ class DataTransformer(BaseModule):
                 if data_subtype == DATA_SUBTYPES.ARRAY:
                     self._apply_to_all_data(input_data, column, _standardize_timeseries, transaction_type)
 
-            if self.transaction.hmd['model_backend'] == 'lightwood':
-                if data_type == DATA_TYPES.DATE:
-                    self._apply_to_all_data(input_data, column, _standardize_datetime, transaction_type, fmt=self.transaction.lmd['stats_v2'][column]['additional_info']['date_fmt'])
-                    self._apply_to_all_data(input_data, column, _lightwood_datetime_processing, transaction_type)
-                    self._apply_to_all_data(input_data, column, _handle_nan, transaction_type)
-
         # Initialize this here, will be overwritten if `equal_accuracy_for_all_output_categories` is specified to be True in order to account for it
         self.transaction.lmd['weight_map'] = self.transaction.lmd['output_categories_importance_dictionary']
 
